@@ -21,7 +21,7 @@
 
 #include <gnome.h>
 
-gboolean gok_page_wordcomplete_initialize (GtkWidget* pWindowSettings);
+gboolean gok_page_wordcomplete_initialize (GladeXML* xml);
 void gok_page_wordcomplete_refresh (void);
 gboolean gok_page_wordcomplete_apply (void);
 gboolean gok_page_wordcomplete_revert (void);
